Color
=====

.. currentmodule:: pywwt.traits

.. autoclass:: Color
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~Color.validate

   .. rubric:: Methods Documentation

   .. automethod:: validate
